This test will download the reference databases.

This test should preferably run before all the other test cases, hence the use of "actualize" to set at the top of the alphabetically sorted list of pytests.